
#include	<stdio.h>
#include	<stdlib.h>
#include	<unistd.h>
#include	<string.h>
#include	<sys/io.h>

/* pick your parport adress */
#define base 0x378
//#define base 0x379
//#define base 0x37A
//#define base 0x3bc
//#define base 0x278

class meskalin
{
public:
		//basic interface functions
	void	usage(char *self);
	int	getfreq(char *group);
	int	getint(char *string);
	
		//patterns:
	void	normal(int frequency);
	void	flipflop(int frequency);
	void	chasing(int frequency, char *type);
	void	windowlicker(int frequency, char *option);
	
		//specials:
	void	reset(void);
	void	freqvar(char *type, char *pattern);
	void	address(int address);
	void	led(int led);
	
		//misc
	void	startio(void);

};

meskalin meskalin;

